@@ -78,7 +78,7 @@ class NativeTransport(object):
         if headers is None:
             headers={}
 
-        if 'content-type' in headers:
+        if 'Content-Type' in headers:
             if headers['Content-Type'] == 'application/json':
                 body=json.dumps(body)
 
